@@ -3,67 +3,79 @@ package Lazy::Bool;
 use 5.010000;
 use strict;
 use warnings;
+use Exporter 'import';
 
-our $VERSION = '0.04.1';
+our $VERSION   = '0.05.1';
+our @EXPORT_OK = qw(lzb);
+
+sub lzb(&) {
+    my $code = shift;
+    __PACKAGE__->new($code);
+}
 
 sub new {
-  my ($type, $code) = @_;
-	
-	my $klass = ref($type) || $type;
-	
-	my $ref = (ref($code) eq 'CODE')? $code : sub { $code };
-	
-	bless $ref => $klass;
+    my ( $type, $code ) = @_;
+    my $klass = ref($type) || $type;
+    my $ref = ( ref($code) eq 'CODE' ) ? $code : sub { $code };
+
+    bless $ref => $klass;
 }
 
 sub true {
-	shift->new( sub{ 1 })
+    shift->new( sub { 1 } );
 }
 
 sub false {
-	shift->new( sub{ 0 })
+    shift->new( sub { 0 } );
 }
 
-use overload 
-	'bool' => \&_to_bool,
-	'&'    => \&_lazy_and,
-	'|'    => \&_lazy_or, 
-	'!'    => \&_lazy_neg;
+use overload
+  'bool' => \&_to_bool,
+  '&'    => \&_lazy_and,
+  '|'    => \&_lazy_or,
+  '!'    => \&_lazy_neg;
 
 sub _to_bool {
-	shift->()
-}	
+    shift->();
+}
 
 sub _lazy_and {
-	my ($a, $b) = @_;
-	
-	$a->new(sub {
-		my $real = $a->_to_bool;
-		
-		return $real unless $real;
-		
-		$real & $b
-	})
+    my ( $a, $b ) = @_;
+
+    $a->new(
+        sub {
+            my $real = $a->_to_bool;
+
+            return $real unless $real;
+
+            $real & $b;
+        }
+    );
 }
 
 sub _lazy_or {
-	my ($a, $b) = @_;
-	
-	$a->new(sub {
-		my $real = $a->_to_bool; 
-		
-		return $real if $real;
-		
-		$real | $b
-	})
+    my ( $a, $b ) = @_;
+
+    $a->new(
+        sub {
+            my $real = $a->_to_bool;
+
+            return $real if $real;
+
+            $real | $b;
+        }
+    );
 }
 
 sub _lazy_neg {
-	my $a  = shift;
-	$a->new(sub { 
-			! $a->_to_bool
-	})
+    my $a = shift;
+    $a->new(
+        sub {
+            !$a->_to_bool;
+        }
+    );
 }
+
 1;
 __END__
 # Below is stub documentation for your module. You'd better edit it!
@@ -76,16 +88,18 @@ Lazy::Bool - Boolean wrapper lazy
 
   use Lazy::Bool;
 
-  my $result = Lazy::Bool->new(sub{  
+  my $result = Lazy::Bool->new(sub{
   	# complex boolean expression
   });
 
-  ...
+  #...
   if($result) { # now we evaluate the expression
-	
+
   }
 
-Using this module you can play with lazy booleans. Using expressions &, | and ! you can delay the expression evaluation until necessary.
+ # Using this module you can play with lazy booleans. 
+ 
+ # Using expressions &, | and ! you can delay the expression evaluation until necessary.
 
 =head1 DESCRIPTION
 
@@ -97,10 +111,10 @@ The expression will be evaluated in boolean context, like
   unless($lazy_boolean) { }
 
   $lazy_boolean && $other  # for a lazy operation use the &
-  $lazy_boolean || $other  # for a lazy operation use the | 
+  $lazy_boolean || $other  # for a lazy operation use the |
 
 =head1 METHODS
-	
+
 =head2 new
 
 The constructor, can receive one expression or a subroutine reference.
@@ -109,8 +123,8 @@ The constructor, can receive one expression or a subroutine reference.
 
   my $result1 = Lazy::Bool->new( 1 );
 
-  my $result2 = Lazy::Bool->new(sub{ 
-    $a > $b && $valid 
+  my $result2 = Lazy::Bool->new(sub{
+    $a > $b && $valid
   });
 
 =head2 true
@@ -173,6 +187,18 @@ Used as a logical negation (not), you can create a lazy negation.
 
   print "success" if $result; # now will be evaluated!
 
+=head2 Functions
+
+=head3 lzb
+
+Helper to create an instance.
+
+  use Lazy::Bool qw(lzb);
+
+  my $a = 6;
+  my $b = 4;
+  my $condition = lzb { $a > $b };
+
 =head2 EXAMPLES
 
 A complex example:
@@ -193,7 +219,7 @@ A complex example:
 	
 =head1 EXPORT
 
-None 
+This package can export the helper lzbc to easily create a new instance of Lazy::Bool
 
 =head1 SEE ALSO
 
